@@ -1,7 +1,7 @@
 __project_name__ = 'upsies'
 __description__ = 'Media metadata aggregator'
 __homepage__ = 'https://upsies.readthedocs.io'
-__version__ = '2021.11.09'
+__version__ = '2021.12.09'
 __author__ = 'plotski'
 __author_email__ = 'plotski@example.org'
 
@@ -18,7 +18,7 @@ def application_setup(config):
 
     utils.http.cache_directory = os.path.join(
         config['config']['main']['cache_directory'],
-        'http',
+        'http_responses',
     )
 
 
