@@ -5,8 +5,17 @@ from . import constants, trackers, utils
 defaults = {
     'config': {
         'main': {
-            'cache_directory': constants.CACHE_DIRPATH,
-            'max_cache_size': utils.types.Bytes.from_string('20 MB'),
+            'cache_directory': utils.configfiles.config_value(
+                value=constants.DEFAULT_CACHE_DIRECTORY,
+                description='Where to store generated files.',
+            ),
+            'max_cache_size': utils.configfiles.config_value(
+                value=utils.types.Bytes.from_string('20 MB'),
+                description=(
+                    'Maximum size of cache directory. '
+                    'Units like "kB" and "MiB" are interpreted.'
+                ),
+            ),
         },
     },
 
