@@ -63,17 +63,29 @@ class BhdTrackerJobs(TrackerJobsBase):
         :param str job_attr: Name of the job attribute this condition is for
         """
         def condition():
-            if self.options['description']:
-                # Only activate description_job and its dependencies
-                return job_attr in ('description_job', 'screenshots_job', 'upload_screenshots_job')
-            elif self.options['title']:
-                # Only activate release_name_job and its dependencies
-                return job_attr in ('release_name_job', 'imdb_job')
+            isolated_jobs = self.isolated_jobs
+            if isolated_jobs:
+                return job_attr in isolated_jobs
             else:
                 return True
 
         return condition
 
+    @property
+    def isolated_jobs(self):
+        """
+        Sequence of attribute names (e.g. "imdb_job") that were singled out by the
+        user, e.g. with a CLI argument
+        """
+        if self.options.get('only_description', False):
+            # Only activate description_job and its dependencies
+            return ('description_job', 'screenshots_job', 'upload_screenshots_job')
+        elif self.options.get('only_title', False):
+            # Only activate release_name_job and its dependencies
+            return ('release_name_job', 'imdb_job')
+        else:
+            return ()
+
     @cached_property
     def imdb_job(self):
         imdb_job = super().imdb_job
@@ -256,6 +268,8 @@ class BhdTrackerJobs(TrackerJobsBase):
             cells = []
             for screenshot in screenshots:
                 if screenshot is not None:
+                    if screenshot.thumbnail_url is None:
+                        raise RuntimeError(f'No thumbnail for {screenshot}')
                     cells.append(f'[url={screenshot}][img]{screenshot.thumbnail_url}[/img][/url]')
             # Space between columns
             rows.append(' '.join(cells))
@@ -304,13 +318,15 @@ class BhdTrackerJobs(TrackerJobsBase):
             tags.append('DualAudio')
         if 'Open Matte' in self.release_name.edition:
             tags.append('OpenMatte')
+        if '2in1' in self.release_name.edition:
+            tags.append('2in1')
+        if '4k Remastered' in self.release_name.edition:
+            tags.append('4kRemaster')
         if self.get_job_attribute(self.scene_check_job, 'is_scene_release'):
             tags.append('Scene')
         if self.options['personal_rip']:
             tags.append('Personal')
 
-        # TODO: 4kRemaster (waiting for https://github.com/guessit-io/guessit/pull/701)
-        # TODO: 2in1 (waiting for https://github.com/guessit-io/guessit/pull/702)
         # TODO: 2D3D
         # TODO: 3D
         # TODO: EnglishDub
@@ -325,7 +341,7 @@ class BhdTrackerJobs(TrackerJobsBase):
         `False` if :attr:`~.TrackerJobsBase.options` prevents submission for any
         reason, parent class implementation otherwise
         """
-        if self.options['description'] or self.options['title']:
+        if self.isolated_jobs:
             return False
         else:
             return super().submission_ok
