@@ -22,7 +22,6 @@ class NblTrackerConfig(base.TrackerConfigBase):
         'password'   : '',
         'exclude'    : [],
         'source'     : 'NBL',
-        'image_host' : '',
     }
 
     argument_definitions = {
@@ -214,6 +213,7 @@ class NblTracker(base.TrackerBase):
         )
 
         # Upload response should redirect to torrent page via "Location" header
+        _log.debug('Looking for "Location" in response headers: %r', response.headers)
         torrent_page_url = urllib.parse.urljoin(
             self.options['base_url'],
             response.headers.get('Location', ''),
@@ -228,7 +228,7 @@ class NblTracker(base.TrackerBase):
             if error and error.string:
                 _log.debug('NBL error: %r', doc)
                 if 'torrent contained one or more possible dupes' in error.string:
-                    msg = f'{error.string}\nUse --ignore-dupes to enforce the upload.'
+                    msg = f'{error.string}\nUse --ignore-dupes to force the upload.'
                 else:
                     msg = error.string
                 raise errors.RequestError(f'Upload failed: {msg}')
