@@ -2,7 +2,7 @@
 Generate all required metadata and upload to tracker
 """
 
-from .... import jobs, trackers, utils
+from .... import constants, jobs, trackers, utils
 from .base import CommandBase
 
 
@@ -39,6 +39,14 @@ class submit(CommandBase):
                         'type': utils.argtypes.regex,
                         'default': (),
                     },
+                    ('--reuse-torrent', '-t'): {
+                        'metavar': 'TORRENT',
+                        'help': ('Use hashed pieces from TORRENT instead of generating '
+                                 'them again or getting them from '
+                                 f'{utils.fs.tildify_path(constants.GENERIC_TORRENTS_DIRPATH)}\n'
+                                 "NOTE: This option is ignored if TORRENT doesn't match properly."),
+                        'type': utils.argtypes.existing_path,
+                    },
                     ('--add-to', '-a'): {
                         'type': utils.argtypes.client,
                         'metavar': 'CLIENT',
@@ -106,6 +114,7 @@ class submit(CommandBase):
         return self.tracker.TrackerJobs(
             options=self.tracker_options,
             content_path=self.args.CONTENT,
+            reuse_torrent_path=self.args.reuse_torrent,
             tracker=self.tracker,
             image_host=self._get_imghost(),
             bittorrent_client=self._get_btclient(),
@@ -140,7 +149,7 @@ class submit(CommandBase):
 
     def _get_btclient(self):
         btclient_name = (getattr(self.args, 'add_to', None)
-                         or self.tracker_options.get('add-to', None)
+                         or self.tracker_options.get('add_to', None)
                          or None)
         if btclient_name:
             return utils.btclients.client(
@@ -150,5 +159,5 @@ class submit(CommandBase):
 
     def _get_torrent_destination(self):
         return (getattr(self.args, 'copy_to', None)
-                or self.tracker_options.get('copy-to', None)
+                or self.tracker_options.get('copy_to', None)
                 or None)
