@@ -1,7 +1,8 @@
-import asyncio
 import itertools
 import sys
 
+from ... import utils
+
 import logging  # isort:skip
 _log = logging.getLogger(__name__)
 
@@ -63,4 +64,4 @@ class Throbber:
         if self.active:
             if self._callback:
                 self._callback(self.next_state)
-            asyncio.get_event_loop().call_later(self._interval, self._iterate)
+            utils.get_aioloop().call_later(self._interval, self._iterate)
