@@ -37,6 +37,7 @@ def os_family():
 
 
 try:
+    # New in Python 3.8
     from functools import cached_property
 except ImportError:
     import functools
@@ -59,6 +60,13 @@ except ImportError:
                 return value
 
 
+try:
+    # New in Python 3.7
+    from contextlib import asynccontextmanager
+except ImportError:
+    from async_generator import asynccontextmanager
+
+
 # https://github.com/tensorflow/tensorflow/blob/master/tensorflow/python/util/lazy_loader.py
 class LazyModule(_types.ModuleType):
     """
