@@ -47,14 +47,14 @@ def projectdir(content_path, base=None):
 
     :param str content_path: Path to torrent content
     :param str base: Location of the project directory; defaults to
-        :attr:`~.constants.CACHE_DIRPATH`
+        :attr:`~.constants.DEFAULT_CACHE_DIRECTORY`
 
     :raise ContentError: if `content_path` exists and is not a directory or has
         insufficient permissions
     """
     if content_path:
         if not base:
-            base = constants.CACHE_DIRPATH
+            base = constants.DEFAULT_CACHE_DIRECTORY
         path = os.path.join(base, basename(content_path) + f'.{__project_name__}')
     else:
         path = '.'
@@ -236,7 +236,6 @@ def sanitize_filename(filename):
         illegal_chars = ('<', '>', ':', '"', '/', '\\', '|', '?', '*')
     else:
         illegal_chars = ('/',)
-
     for char in illegal_chars:
         filename = filename.replace(char, '_')
     return filename
@@ -248,9 +247,15 @@ def sanitize_path(path):
 
     `path` is split at :attr:`os.sep` and the resulting items are passed to
     :func:`sanitize_filename` and joined.
+
+    On Windows, the drive (e.g. "C:") is not sanitized to keep the ":".
     """
+    # Get drive from Windows paths (e.g. "C:") because we don't want to sanitize
+    # the ":", which is illegal otherwise
+    drive, path = os.path.splitdrive(path)
     segments = str(path).split(os.sep)
-    return os.sep.join(sanitize_filename(segment) for segment in segments)
+    sanitized_segments = [sanitize_filename(segment) for segment in segments]
+    return drive + os.sep.join(sanitized_segments)
 
 
 def tildify_path(path):
