@@ -19,7 +19,7 @@ import natsort
 import unidecode
 
 from .. import constants, errors
-from ..utils import scene, webdbs
+from ..utils import iso, scene, webdbs
 from . import LazyModule, cached_property, fs, video
 from .types import ReleaseType
 
@@ -55,9 +55,9 @@ class _translated_property:
             return self
         else:
             value = self.fget(obj)
-            return self._translate(value, obj._translate)
+            return self._apply_translation(value, obj._translate)
 
-    def _translate(self, value, tables):
+    def _apply_translation(self, value, tables):
         def translate(string):
             table = tables.get(self.name, {})
             for regex, replacement in table.items():
@@ -243,13 +243,14 @@ class ReleaseName(collections.abc.Mapping):
         """
         Combination of :attr:`title`, :attr:`title_aka` and :attr:`year`
 
-        For movies, the :attr:`year` is always appended to the
-        :attr:`title`. For series, the :attr:`year` is appended if
-        :attr:`year_required` is `True`.
+        If :attr:`year_required` is `True`, :attr:`year` is appended.
+        If :attr:`country_required` is `True`, :attr:`country` is appended.
 
         :attr:`title_aka` is appended if it is truthy.
         """
         title = [self.title_with_aka]
+        if self.country_required:
+            title.append(self.country)
         if self.year_required:
             title.append(self.year)
         return ' '.join(title)
@@ -294,6 +295,40 @@ class ReleaseName(collections.abc.Mapping):
     def year_required(self, value):
         self._year_required = bool(value)
 
+    @_translated_property
+    def country(self):
+        """
+        Release country or "UNKNOWN_COUNTRY" if :attr:`country_required` is set,
+        empty string otherwise
+
+        See also :meth:`fetch_info`.
+        """
+        country = self._info.get('country')
+        if self.country_required:
+            return country or 'UNKNOWN_COUNTRY'
+        else:
+            return country or ''
+
+    @country.setter
+    def country(self, value):
+        if not value:
+            self._info['country'] = ''
+        else:
+            self._info['country'] = str(value)
+
+    @property
+    def country_required(self):
+        """
+        Whether :attr:`title_with_aka_and_year` includes :attr:`country`
+
+        See also :meth:`fetch_info`.
+        """
+        return getattr(self, '_country_required', False)
+
+    @country_required.setter
+    def country_required(self, value):
+        self._country_required = bool(value)
+
     @_translated_property
     def episodes(self):
         """
@@ -615,6 +650,8 @@ class ReleaseName(collections.abc.Mapping):
           - :attr:`type`
           - :attr:`year`
           - :attr:`year_required`
+          - :attr:`country`
+          - :attr:`country_required`
 
         :return: The method's instance (`self`) for convenience
         """
@@ -625,7 +662,7 @@ class ReleaseName(collections.abc.Mapping):
             db = getattr(self, db_name)
             await self._update_attributes(db, id)
         await self._update_type(self._imdb, id)
-        await self._update_year_required()
+        await self._update_year_country_required()
         _log.debug('Release name updated with IMDb info: %s', self)
 
         if callback is not None:
@@ -638,6 +675,7 @@ class ReleaseName(collections.abc.Mapping):
             'title_english',
             'title_original',
             'year',
+            'countries',
         )
         for attr, key in (
             ('title', 'title_original'),
@@ -648,6 +686,9 @@ class ReleaseName(collections.abc.Mapping):
             if info[key]:
                 setattr(self, attr, info[key])
 
+        if info['countries']:
+            self.country = iso.country_tld(info['countries'][0]).upper()
+
     async def _update_type(self, db, id):
         # Use type from database if possible. ReleaseInfo can misdetect type
         # (e.g. if mini-series doesn't contain "S01"). But if ReleaseInfo
@@ -656,21 +697,44 @@ class ReleaseName(collections.abc.Mapping):
         if db_type and self.type is not ReleaseType.episode:
             self.type = db_type
 
-    async def _update_year_required(self):
+    async def _update_year_country_required(self):
         if self.type in (ReleaseType.season, ReleaseType.episode):
-            # Find out if there are multiple series with this title
-            query = webdbs.Query(title=self.title, type=ReleaseType.series)
-            results = await self._imdb.search(query)
-
             def normalize_title(title):
                 return unidecode.unidecode(title.casefold())
 
+            # Find result with the same title, removing any "smart" matches
             title_normalized = normalize_title(self.title)
-            same_titles = tuple(f'{r.title} year={r.year} imdb_id={r.id}' for r in results
-                                if normalize_title(r.title) == title_normalized)
-            if len(same_titles) >= 2:
-                _log.debug('Found multiple search results for %r: %r', query, same_titles)
-                self.year_required = True
+            query = webdbs.Query(title=self.title, type=ReleaseType.series)
+            results = [
+                {
+                    'title': normalize_title(result.title),
+                    'year': result.year,
+                    'countries': await result.countries(),
+                }
+                for result in await self._imdb.search(query)
+                if title_normalized == normalize_title(result.title)
+            ]
+
+            def has_duplicates(seq):
+                tupl = tuple(seq)
+                for item in tupl:
+                    if tupl.count(item) > 1:
+                        return True
+                return False
+
+            def make_title(result, country=False, year=False):
+                parts = [result['title']]
+                if country and result['countries']:
+                    parts.append(result['countries'][0])
+                if year and result['year']:
+                    parts.append(result['year'])
+                return ','.join(parts)
+
+            if has_duplicates(make_title(r) for r in results):
+                if not has_duplicates(make_title(r, country=True) for r in results):
+                    self.country_required = True
+                elif not has_duplicates(make_title(r, year=True) for r in results):
+                    self.year_required = True
 
     def format(self, sep=' '):
         """Assemble all parts into string"""
@@ -909,6 +973,19 @@ class ReleaseInfo(collections.abc.MutableMapping):
     def _get_year(self):
         return _as_string(self._guess.get('year') or '')
 
+    _country_translation = {
+        'UK': re.compile(r'^GB$'),
+    }
+
+    def _get_country(self):
+        country = iso.country_tld(
+            _as_string(self._guess.get('country') or '')
+        ).upper()
+        for country_, regex in self._country_translation.items():
+            if regex.search(country):
+                country = country_
+        return country
+
     def _get_episodes(self):
         if 'episodes' not in self._guess:
             self._guess['episodes'] = Episodes()
