@@ -18,7 +18,7 @@ torf = LazyModule(module='torf', namespace=globals())
 
 def create(*, content_path, announce, source, torrent_path,
            init_callback, progress_callback,
-           overwrite=False, exclude=()):
+           overwrite=False, exclude=(), reuse_torrent_path=None):
     """
     Generate and write torrent file
 
@@ -59,6 +59,10 @@ def create(*, content_path, announce, source, torrent_path,
     :param bool overwrite: Whether to overwrite `torrent_path` if it exists
     :param exclude: Sequence of regular expressions that are matched against
         file system paths. Matching files are not included in the torrent.
+    :param reuse_torrent_path: Path to existing torrent file to get hashed
+        pieces and piece size from. This argument is ignored if the files in the
+        provided torrent do not match the files we want or if it can't be read
+        for any reason.
 
     :raise TorrentError: if anything goes wrong
 
@@ -75,12 +79,15 @@ def create(*, content_path, announce, source, torrent_path,
         # Try to read piece hashes from cache
         torrent = _read_cache_torrent(
             content_path=content_path,
+            cache_torrent_path=reuse_torrent_path,
             exclude=exclude,
         )
         if torrent:
             # Update metadata in generic torrent
             torrent.trackers = (announce,)
             torrent.source = source
+            if reuse_torrent_path:
+                _store_cache_torrent(torrent)
         else:
             # Reading cached piece hashes failed for some reason
             torrent = _generate_torrent(
@@ -132,11 +139,12 @@ def _store_cache_torrent(torrent):
     )
     _copy_torrent_info(torrent, cache_torrent)
     cache_torrent_path = _get_cache_torrent_path(cache_torrent, create_directory=True)
-    cache_torrent.write(cache_torrent_path)
+    cache_torrent.write(cache_torrent_path, overwrite=True)
 
 
-def _read_cache_torrent(content_path, exclude):
+def _read_cache_torrent(content_path, exclude, cache_torrent_path=None):
     try:
+        # Create the Torrent we're going to use
         torrent = torf.Torrent(
             path=content_path,
             exclude_regexs=exclude,
@@ -144,35 +152,42 @@ def _read_cache_torrent(content_path, exclude):
             created_by=f'{__project_name__} {__version__}',
             creation_date=time.time(),
         )
-        cache_torrent_path = _get_cache_torrent_path(torrent, create_directory=False)
+        # Create the Torrent to get hashed pieces from
+        if not cache_torrent_path:
+            cache_torrent_path = _get_cache_torrent_path(torrent, create_directory=False)
         cache_torrent = torf.Torrent.read(cache_torrent_path)
     except torf.TorfError:
-        return None
+        pass
     else:
-        _copy_torrent_info(cache_torrent, torrent)
-        return torrent
+        # Make sure the cached torrent metainfo matches what we expect
+        id_wanted = _get_torrent_id(torrent)
+        id_cached = _get_torrent_id(cache_torrent)
+        if id_cached == id_wanted:
+            _copy_torrent_info(cache_torrent, torrent)
+            return torrent
 
 
 def _get_cache_torrent_path(torrent, create_directory=True):
-    directory = os.path.join(
-        constants.CACHE_DIRPATH,
-        'generic_torrents',
-    )
+    directory = constants.GENERIC_TORRENTS_DIRPATH
     if create_directory:
         try:
             fs.mkdir(directory)
         except errors.ContentError as e:
             raise errors.TorrentError(f'{directory}: {e}')
 
-    cache_id = {
-        'files': [(str(f), f.size) for f in torrent.files],
-        'piece_size': torrent.piece_size,
-    }
-    cache_id_string = utils.semantic_hash(cache_id)
-    filename = f'{torrent.name}.{cache_id_string}.torrent'
+    cache_id = _get_torrent_id(torrent)
+    filename = f'{torrent.name}.{cache_id}.torrent'
     return os.path.join(directory, filename)
 
 
+def _get_torrent_id(torrent):
+    id_info = {
+        'name': torrent.name,
+        'files': tuple((str(f), f.size) for f in torrent.files),
+    }
+    return utils.semantic_hash(id_info)
+
+
 def _copy_torrent_info(from_torrent, to_torrent):
     from_info, to_info = from_torrent.metainfo['info'], to_torrent.metainfo['info']
     to_info['pieces'] = from_info['pieces']
@@ -320,7 +335,7 @@ class TorrentFileStream:
 
     Example:
     >>> torrent = torf.Torrent(...)
-    >>> TorrentFileStream(torrent, location='path/to/files') as tfs:
+    >>> with TorrentFileStream(torrent, location='path/to/files') as tfs:
     >>>     # Get the 29th piece of the concatenated file stream
     >>>     piece = tfs.get_piece(29)
     """
@@ -334,6 +349,15 @@ class TorrentFileStream:
         return self
 
     def __exit__(self, exc_type, exc_value, traceback):
+        self.close()
+
+    def close(self):
+        """
+        Close all opened files
+
+        This is called automatically when the instance is used as a context
+        manager.
+        """
         for filepath, fh in tuple(self._open_files.items()):
             fh.close()
             del self._open_files[filepath]
