@@ -161,7 +161,7 @@ def default_track(type, path, default=NO_DEFAULT_VALUE):
     except (KeyError, IndexError):
         pass
 
-    raise errors.ContentError(f'{path}: No {type.lower()} track found')
+    raise errors.ContentError(f'{path}: No {type.lower()} track found: {all_tracks!r}')
 
 
 def width(path, default=NO_DEFAULT_VALUE):
@@ -245,19 +245,17 @@ def resolution(path, default=NO_DEFAULT_VALUE):
         return default
 
     video_track = default_track('video', path)
-    try:
-        std_resolution = _get_closest_standard_resolution(video_track)
-    except errors.ContentError:
-        raise errors.ContentError('Unable to determine video resolution')
+    std_resolution = _get_closest_standard_resolution(video_track)
+    scan_type = _scan_type(video_track)
+    return f'{std_resolution}{scan_type}'
+
+def _scan_type(video_track):
+    # "p" or "i", default to "p"
+    scan_type = str(video_track.get('ScanType', 'Progressive')).lower()
+    if scan_type in ('interlaced', 'mbaff', 'paff'):
+        return 'i'
     else:
-        try:
-            # "p" or "i", default to "p"
-            scan = video_track.get('ScanType', 'Progressive')[0].lower()
-        except (KeyError, IndexError, TypeError):
-            raise errors.ContentError('Unable to determine video resolution')
-        else:
-            _log.debug('Detected resolution: %s%s', std_resolution, scan)
-            return f'{std_resolution}{scan}'
+        return 'p'
 
 _standard_resolutions = (
     # (width, height, standard resolution)
@@ -462,7 +460,8 @@ def has_commentary(path, default=NO_DEFAULT_VALUE):
 
     audio_tracks = tracks(path).get('Audio', ())
     for track in audio_tracks:
-        if 'commentary' in track.get('Title', '').lower():
+        title = track.get('Title', '').lower()
+        if any(word in title for word in ('commentary', 'comments')):
             return True
     return False
 
